@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_client_types_h =
- *   "$Id: client-types.h 4963 2006-09-21 05:50:22Z mwedel $";
+ *   "$Id: client-types.h 6716 2007-06-27 18:57:31Z akirschbaum $";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -32,7 +32,7 @@
 /* If using autoconf, use it to pick up the necessary files.  Otherwise,
  * we will draw on includes.h
  */
-#include "config.h"
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/types.h>
@@ -113,7 +113,7 @@ typedef signed char       sint8;
 #define MAX_BUF 256
 #define BIG_BUF 1024
 
-/* used to register gui callbacks to extended texts 
+/* used to register gui callbacks to extended texts
  * (which are supposed to be handled more friendly than raw text)*/
 typedef void (*ExtTextManager)(int flag, int type, int subtype, char* message);
 
