@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_client_h =
- *   "$Id: client.h 5076 2006-11-04 08:15:16Z mwedel $";
+ *   "$Id: client.h 7552 2007-11-20 20:44:54Z tchize $";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -241,7 +241,7 @@ typedef struct Spell_struct {
     uint8 skill_number; /* the index in the skill arrays, plus CS_STAT_SKILLINFO */
     char *skill; /* pointer to the skill name, derived from the skill number */
     uint32 path; /* the bitmask of paths this spell belongs to */
-    sint32 face; 
+    sint32 face;
 } Spell;
 
 typedef struct Player_Struct {
@@ -261,7 +261,7 @@ typedef struct Player_Struct {
     Spell	*spelldata;	/* linked list of spells known to the player */
     char	title[MAX_BUF];	/* Title of character */
     char	range[MAX_BUF];	/* Range attack chosen */
-    uint32	spells_updated; /* tracks whether the spells updated*/ 
+    uint32	spells_updated; /* tracks whether the spells updated*/
     uint32	fire_on:1;	/* True if fire key is pressed */
     uint32	run_on:1;	/* True if run key is on */
     uint32	meta_on:1;	/* True if fire key is pressed */
@@ -345,7 +345,20 @@ typedef struct LogEntry{
 extern LogEntry* LogFirst;
 extern LogEntry* LogLast;
 typedef void (*LogListener)(LogEntry*);
-#define LOG_APPEND(_Entry) if (LogLast) {LogLast->next=_Entry;} else {LogFirst=_Entry;};LogLast=_Entry;_Entry->next=NULL
+#define MAX_LOGS 200
+#define LOG_APPEND(_Entry) if (LogLast) {\
+    LogLast->next=_Entry;\
+  } else {\
+    LogFirst=_Entry;\
+  };\
+  LogLast=_Entry;_Entry->next=NULL;\
+  if (++logcount > MAX_LOGS)\
+  {\
+      LogEntry* old = LogFirst;\
+      LogFirst = LogFirst -> next;\
+      if (old->message) free (old->message);\
+      if (old->origin) free (old->origin);\
+  }
 #define LOG_NEW_ENTRY (LogEntry*)calloc(1,sizeof(LogEntry))
 #define LOG_SETMESSAGE(_Entry,_msg) free(_Entry->message);_Entry->message=strdup(_msg)
 #define LOG_SETORIGIN(_Entry,_orig) free(_Entry->origin);_Entry->origin=strdup(_orig)
@@ -387,12 +400,14 @@ typedef struct ChildProcess{
 extern const char *const resists_name[NUM_RESISTS];
 extern char *meta_server;
 extern int meta_port,want_skill_exp;
-extern int map1cmd,metaserver_on;
+extern int metaserver_on, metaserver2_on;
 extern uint32	tick;
 
 extern uint64	*exp_table;
 extern uint16	exp_table_max;
 
+extern int command_inscribe;
+
 /* Map size the client will request the map to be.  Bigger it is,
  * more memory it will use
  */
