@@ -1,5 +1,5 @@
 const char *rcsid_common_image_c =
-    "$Id: image.c 4963 2006-09-21 05:50:22Z mwedel $";
+    "$Id: image.c 8129 2008-01-05 20:13:05Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -28,7 +28,7 @@ const char *rcsid_common_image_c =
  * from the server, etc.
  */
 
-#include "config.h"
+#include <config.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #ifndef WIN32
@@ -73,7 +73,7 @@ static int load_image(char *filename, uint8 *data, int *len, uint32 *csum)
      * In fact, we keep track of which ones we have opened to improve
      * performance.  Note that while not currently done, this combined
      * image scheme could be done when storing images in the players
-     * ~/.crossfire-images directory.
+     * ~/.crossfire/image-cache directory.
      */
     if ((cp=strchr(filename,'@'))!=NULL) {
 	char *lp;
@@ -166,8 +166,6 @@ static int load_image(char *filename, uint8 *data, int *len, uint32 *csum)
 
 Face_Information face_info;
 
-char	home_dir[MAX_BUF];
-
 /* This holds the name we recieve with the 'face' command so we know what
  * to save it as when we actually get the face.
  */
@@ -259,7 +257,7 @@ static void image_remove_hash(char *imagename, Cache_Entry *ce)
  * do a checksum comparison.
  */
 
-static Cache_Entry *image_find_cache_entry(char *imagename, uint32 checksum, int has_sum) 
+static Cache_Entry *image_find_cache_entry(char *imagename, uint32 checksum, int has_sum)
 {
     int	hash_entry;
     Cache_Entry	*entry;
@@ -283,7 +281,7 @@ static Cache_Entry *image_add_hash(char *imagename, char *filename, uint32 check
     uint32  hash = image_hash_name(imagename, IMAGE_HASH), newhash;
 
     newhash = hash;
-    while (image_cache[newhash].image_name != NULL && 
+    while (image_cache[newhash].image_name != NULL &&
       strcmp(image_cache[newhash].image_name, imagename)) {
 	newhash ++;
 	if (newhash == IMAGE_HASH) newhash=0;
@@ -347,7 +345,7 @@ void init_common_cache_data()
     memset(image_cache, 0, IMAGE_HASH * sizeof(struct Image_Cache));
 
 
-    sprintf(bmaps,"%s/bmaps.client",DATADIR);
+    sprintf(bmaps,"%s/bmaps.client",CF_DATADIR);
     if ((fp=fopen(bmaps,"r"))!=NULL) {
 	while (fgets(inbuf, MAX_BUF-1, fp)!=NULL) {
 	    image_process_line(inbuf, 1);
@@ -358,7 +356,7 @@ void init_common_cache_data()
 	draw_info(inbuf, NDI_RED);
     }
 
-    sprintf(bmaps,"%s/.crossfire/crossfire-images/bmaps.client", getenv("HOME"));
+    sprintf(bmaps,"%s/.crossfire/image-cache/bmaps.client", getenv("HOME"));
     if ((fp=fopen(bmaps,"r"))!=NULL) {
 	while (fgets(inbuf, MAX_BUF-1, fp)!=NULL) {
 	    image_process_line(inbuf, 0);
@@ -372,10 +370,6 @@ void init_common_cache_data()
 }
 
 
-void requestsmooth (int pnum){
-    cs_print_string (csocket.fd, "asksmooth %d",pnum);
-}
-
 /******************************************************************************
  *
  * Code related to face caching.
@@ -435,9 +429,9 @@ void finish_face_cmd(int pnum, uint32 checksum, int has_sum, char *face, int fac
 	}
 	if (ce->ispublic)
 	    sprintf(filename,"%s/%s",
-		    DATADIR, ce->filename);
+		    CF_DATADIR, ce->filename);
 	else
-	    sprintf(filename,"%s/.crossfire/crossfire-images/%s",
+	    sprintf(filename,"%s/.crossfire/image-cache/%s",
 		    getenv("HOME"), ce->filename);
 	if (load_image(filename, data, &len, &newsum)==-1) {
 	    LOG(LOG_WARNING,"common::finish_face_cmd","file %s listed in cache file, but unable to load", filename);
@@ -494,47 +488,6 @@ void reset_image_cache_data()
  * if we have already received a face for a particular number.
  */
 
-void FaceCmd(unsigned char *data,  int len)
-{
-    int pnum;
-    char *face;
-
-    /* A quick sanity check, since if client isn't caching, all the data
-     * structures may not be initialized.
-     */
-    if (!use_config[CONFIG_CACHE]) {
-	LOG(LOG_WARNING,"common::FaceCmd","Received a 'face' command when we are not caching");
-	return;
-    }
-    pnum = GetShort_String(data);
-    face = (char*)data+2;
-    data[len] = '\0';
-
-    finish_face_cmd(pnum, 0, 0, face,0);
-
-}
-
-void Face1Cmd(unsigned char *data,  int len)
-{
-    int pnum;
-    uint32  checksum;
-    char *face;
-
-    /* A quick sanity check, since if client isn't caching, all the data
-     * structures may not be initialized.
-     */
-    if (!use_config[CONFIG_CACHE]) {
-	LOG(LOG_WARNING,"common::Face1Cmd","Received a 'face' command when we are not caching");
-	return;
-    }
-    pnum = GetShort_String(data);
-    checksum = GetInt_String(data+2);
-    face = (char*)data+6;
-    data[len] = '\0';
-
-    finish_face_cmd(pnum, checksum, 1, face,0);
-}
-
 void Face2Cmd(uint8 *data,  int len)
 {
     int pnum;
@@ -558,23 +511,8 @@ void Face2Cmd(uint8 *data,  int len)
     finish_face_cmd(pnum, checksum, 1, face,setnum);
 }
 
-void ImageCmd(uint8 *data,  int len)
-{  
-    int pnum,plen;
-
-    pnum = GetInt_String(data);
-    plen = GetInt_String(data+4);
-    if (len<8 || (len-8)!=plen) {
-	LOG(LOG_WARNING,"common::ImageCmd","Lengths don't compare (%d,%d)",
-		(len-8),plen);
-	return;
-    }
-    display_newpng(pnum,data+8,plen,0);
-}
-
-
 void Image2Cmd(uint8 *data,  int len)
-{  
+{
     int pnum,plen;
     uint8 setnum;
 
@@ -589,7 +527,7 @@ void Image2Cmd(uint8 *data,  int len)
     display_newpng(pnum,data+9,plen, setnum);
 }
 
-/* 
+/*
  * This function is called when the server has sent us the actual
  * png data for an image.  If caching, we need to write this
  * data to disk.
@@ -607,17 +545,17 @@ void display_newpng(int face, uint8 *buf, int buflen, int setnum)
 	    LOG(LOG_WARNING,"common::display_newpng","Caching images, but name for %ld not set", face);
 	}
 	/* Make necessary leading directories */
-	sprintf(filename, "%s/.crossfire/crossfire-images",getenv("HOME"));
-	if (access(filename, R_OK | W_OK | X_OK)== -1) 
+	sprintf(filename, "%s/.crossfire/image-cache",getenv("HOME"));
+	if (access(filename, R_OK | W_OK | X_OK)== -1)
 #ifdef WIN32
 	    mkdir(filename);
 #else
 	    mkdir(filename, 0755);
 #endif
 
-	sprintf(filename, "%s/.crossfire/crossfire-images/%c%c", getenv("HOME"),
+	sprintf(filename, "%s/.crossfire/image-cache/%c%c", getenv("HOME"),
 		 facetoname[face][0], facetoname[face][1]);
-	if (access(filename, R_OK | W_OK | X_OK)== -1) 
+	if (access(filename, R_OK | W_OK | X_OK)== -1)
 #ifdef WIN32
 	    mkdir(filename);
 #else
@@ -625,14 +563,14 @@ void display_newpng(int face, uint8 *buf, int buflen, int setnum)
 #endif
 
 	/* If setnum is valid, and we have faceset information for it,
-	 * put that prefix in.  This will make it easier later on to 
+	 * put that prefix in.  This will make it easier later on to
 	 * allow the client to switch image sets on the fly, as it can
 	 * determine what set the image belongs to.
 	 * We also append the number to it - there could be several versions
 	 * of 'face.base.111.x' if different servers have different image
 	 * values.
 	 */
-	if (setnum >=0 && setnum < MAX_FACE_SETS && face_info.facesets[setnum].prefix) 
+	if (setnum >=0 && setnum < MAX_FACE_SETS && face_info.facesets[setnum].prefix)
 	    sprintf(basename,"%s.%s", facetoname[face], face_info.facesets[setnum].prefix);
 	else
 	    strcpy(basename, facetoname[face]);
@@ -643,7 +581,7 @@ void display_newpng(int face, uint8 *buf, int buflen, int setnum)
 	setnum--;
 	do {
 	    setnum++;
-	    sprintf(filename, "%s/.crossfire/crossfire-images/%c%c/%s.%d",
+	    sprintf(filename, "%s/.crossfire/image-cache/%c%c/%s.%d",
 		    getenv("HOME"), facetoname[face][0],
 		    facetoname[face][1], basename, setnum);
 	} while (access(filename, F_OK)==-0);
@@ -676,7 +614,7 @@ void display_newpng(int face, uint8 *buf, int buflen, int setnum)
 	     * built image archives, so only a few faces actually need to get
 	     * downloaded.
 	     */
-	    sprintf(filename,"%s/.crossfire/crossfire-images/bmaps.client", getenv("HOME"));
+	    sprintf(filename,"%s/.crossfire/image-cache/bmaps.client", getenv("HOME"));
 	    if ((tmpfile=fopen(filename, "a"))==NULL) {
 		LOG(LOG_WARNING,"common::display_newpng","Can not open %s for appending", filename);
 	    }
@@ -729,7 +667,7 @@ void get_image_info(uint8 *data, int len)
     if (!cp || (cp - lp) > len) return;
     face_info.bmaps_checksum = strtoul(lp, NULL, 10);	/* need unsigned, so no atoi */
 
-    lp = cp+1; 
+    lp = cp+1;
     cp = strchr(lp, '\n');
     while (cp && (cp - lp) <= len) {
 	*cp++ = '\0';
@@ -766,9 +704,9 @@ void get_image_info(uint8 *data, int len)
      */
     if (face_info.want_faceset && atoi(face_info.want_faceset)==0) {
 	for (onset=0; onset<MAX_FACE_SETS; onset++) {
-	    if (face_info.facesets[onset].prefix && 
+	    if (face_info.facesets[onset].prefix &&
 		!strcasecmp(face_info.facesets[onset].prefix, face_info.want_faceset)) break;
-	    if (face_info.facesets[onset].fullname && 
+	    if (face_info.facesets[onset].fullname &&
 		!strcasecmp(face_info.facesets[onset].fullname, face_info.want_faceset)) break;
 	}
 	if (onset < MAX_FACE_SETS) { /* We found a match */
@@ -782,8 +720,8 @@ void get_image_info(uint8 *data, int len)
 
 }
 
-/* This gets a block of checksums from the server.  This lets it 
- * prebuild the images or what not.  It would probably be 
+/* This gets a block of checksums from the server.  This lets it
+ * prebuild the images or what not.  It would probably be
  * nice to add a gui callback someplace that gives a little status
  * display (18% done or whatever) - that probably needs to be done
  * further up.
@@ -814,7 +752,7 @@ void get_image_sums(char *data, int len)
 
     replyinfo_last_face = stop;
 
-    /* Can't use isspace here, because it matches with tab, ascii code 
+    /* Can't use isspace here, because it matches with tab, ascii code
      * 9 - this results in advancing too many spaces because
      * starting at image 2304, the MSB of the image number will be
      * 9.  Using a check against space will work until we get up to
@@ -835,9 +773,8 @@ void get_image_sums(char *data, int len)
 	 * probably amounts to about 100 images at a time
 	 */
 	finish_face_cmd(imagenum, checksum, 1, (char*)cp, faceset);
-	if (imagenum > stop) 
+	if (imagenum > stop)
 	    LOG(LOG_WARNING,"common::get_image_sums","Received an image beyond our range? %d > %d", imagenum, stop);
 	cp += slen;
     }
 }
-
