@@ -1,5 +1,5 @@
 const char *rcsid_common_item_c =
-    "$Id: item.c 5089 2006-11-06 21:19:39Z akirschbaum $";
+    "$Id: item.c 8075 2008-01-03 11:43:29Z ryo_saeba $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -23,9 +23,6 @@ const char *rcsid_common_item_c =
 */
 
 
-#ifdef WIN32
-#include <windows.h>
-#endif
 #include <ctype.h>      /* needed for isdigit */
 #include <client.h>
 #include <item.h>
@@ -43,10 +40,6 @@ static item *player, *map;      /* these lists contains rest of items */
 #include <item-types.h>
 
 
-/* This should be modified to read the definition from a file */
-void init_item_types(void) {
-}
-
 /* This uses the item_types table above.  We try to figure out if
  * name has a match above.  Matching is done pretty loosely - however
  * we try to match the start of the name because that is more reliable.
@@ -204,7 +197,7 @@ char *get_number(uint32 i) {
     if (i <= 20) {
         return numbers[i];
     } else {
-        sprintf(buf, "%d", i);
+        sprintf(buf, "%u", i);
         return buf;
     }
 }
@@ -315,6 +308,9 @@ item *locate_item(sint32 tag) {
         return cpl.container;
     }
 
+    if (cpl.container && (op = locate_item_from_item(cpl.container->inv, tag)) != NULL)
+        return op;
+
     return NULL;
 }
 
@@ -752,3 +748,25 @@ void animate_objects() {
         }
     }
 }
+
+int can_write_spell_on(item* it) {
+    return (it->type == 661);
+}
+
+void inscribe_magical_scroll(item *scroll, Spell *spell) {
+    SockList sl;
+    uint8 buf[MAX_BUF];
+
+    if (command_inscribe == 0) {
+        LOG(LOG_WARNING, "common::inscribe_magical_scroll", "Called when server doesn't handle inscribe command.");
+        return;
+    }
+    sprintf((char*)buf, "inscribe 0 %d %d", scroll->tag, spell->tag);
+    script_monitor_str((char*)buf);
+    SockList_Init(&sl, buf);
+    SockList_AddString(&sl, "inscribe ");
+    SockList_AddChar(&sl, 0);
+    SockList_AddInt(&sl, scroll->tag);
+    SockList_AddInt(&sl, spell->tag);
+    SockList_Send(&sl, csocket.fd);
+}
