@@ -1,4 +1,4 @@
-/* $Id: mapdata.c 5300 2007-01-07 09:04:10Z ryo_saeba $ */
+/* $Id: mapdata.c 6716 2007-06-27 18:57:31Z akirschbaum $ */
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -226,7 +226,7 @@ static void expand_clear_face_from_layer(int x, int y, int layer)
     assert(0 <= layer && layer < MAXLAYERS);
 
     cell = &the_map.cells[x][y].heads[layer];
-    if (cell->size_x && cell->size_y) 
+    if (cell->size_x && cell->size_y)
 	expand_clear_face(x, y, cell->size_x, cell->size_y, layer);
 }
 
@@ -240,7 +240,7 @@ static void expand_clear_face_from_layer(int x, int y, int layer)
  * if clear is set, clear this face.  If not set, don't clear.  the reason
  * clear may not be set is because this is an animation update - animations
  * must all be the same size, so when we set the data for the space,
- * we will just overwrite the old data.  Problem with clearing is that 
+ * we will just overwrite the old data.  Problem with clearing is that
  * clobbers the animation data.
  */
 static void expand_set_face(int x, int y, int layer, sint16 face, int clear)
@@ -577,75 +577,6 @@ int mapdata_is_inside(int x, int y)
     return(x >= 0 && x < width && y >= 0 && y < height);
 }
 
-void mapdata_set_face(int x, int y, int darkness, sint16 face0, sint16 face1, sint16 face2)
-{
-    int px, py;
-    sint16 face[MAXLAYERS];
-    int is_blank;
-    int i;
-
-    assert(MAP1_LAYERS == 3);
-    face[0] = face0;
-    face[1] = face1;
-    face[2] = face2;
-
-    assert(0 <= x && x < MAX_VIEW);
-    assert(0 <= y && y < MAX_VIEW);
-
-    px = pl_pos.x+x;
-    py = pl_pos.y+y;
-    assert(0 <= px && px < FOG_MAP_SIZE);
-    assert(0 <= py && py < FOG_MAP_SIZE);
-
-    is_blank = face0 == -1 && face1 == -1 && face2 == -1 && darkness == -1;
-
-    if (x < width && y < height) {
-        /* tile is visible */
-
-        if (is_blank) {
-            /* visible tile is now blank ==> do not clear but mark as cleared */
-            if (!the_map.cells[px][py].cleared) {
-                the_map.cells[px][py].cleared = 1;
-                the_map.cells[px][py].need_update = 1;
-
-                expand_need_update_from_layer(px, py, 0);
-                expand_need_update_from_layer(px, py, 1);
-                expand_need_update_from_layer(px, py, 2);
-            }
-        }
-        else {
-            /* visible tile is active ==> update tile */
-
-            the_map.cells[px][py].need_update = 1;
-            if (the_map.cells[px][py].cleared) {
-		assert(MAP1_LAYERS == 3);
-		expand_clear_face_from_layer(px, py, 0);
-		expand_clear_face_from_layer(px, py, 1);
-		expand_clear_face_from_layer(px, py, 2);
-                the_map.cells[px][py].darkness = 0;
-                the_map.cells[px][py].have_darkness = 0;
-            }
-            for (i = 0; i < MAP1_LAYERS; i++) {
-                if (face[i] != -1) {
-                    expand_set_face(px, py, i, face[i], TRUE);
-                }
-            }
-            the_map.cells[px][py].cleared = 0;
-	    if (darkness != -1)
-		set_darkness(px, py, 255-darkness);
-        }
-    }
-    else {
-        /* tile is invisible (outside view area, i.e. big face update) */
-
-        for (i = 0; i < MAP1_LAYERS; i++) {
-            if (is_blank || face[i] != -1) {
-                expand_set_bigface(x, y, i, is_blank ? 0 : face[i], TRUE);
-            }
-        }
-    }
-}
-
 /* mapdate_clear_space() is used by Map2Cmd()
  * Basically, server has told us there is nothing on
  * this space.  So clear it.
@@ -801,7 +732,7 @@ void mapdata_set_smooth(int x, int y, int smooth, int layer)
 void mapdata_clear_old(int x, int y) {
     int px, py;
     int i;
-    
+
     assert(0 <= x && x < MAX_VIEW);
     assert(0 <= y && y < MAX_VIEW);
 
