@@ -1,4 +1,4 @@
-/* $Id: mapdata.h 5300 2007-01-07 09:04:10Z ryo_saeba $ */
+/* $Id: mapdata.h 6708 2007-06-23 18:40:13Z ryo_saeba $ */
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -116,12 +116,6 @@ void mapdata_reset(void);
  */
 void mapdata_set_size(int viewx, int viewy);
 
-/**
- * Updates a tile. Must be called for each entry of a map command received from
- * the server.
- */
-void mapdata_set_face(int x, int y, int darkness, sint16 face0, sint16 face1, sint16 face2);
-
 /**
  * Scrolls the map view. Must be called whenever a map_scroll command was
  * received from the server.
