@@ -1,5 +1,5 @@
 const char *rcsid_common_misc_c =
-    "$Id: misc.c 4963 2006-09-21 05:50:22Z mwedel $";
+    "$Id: misc.c 7552 2007-11-20 20:44:54Z tchize $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -24,7 +24,7 @@ const char *rcsid_common_misc_c =
 
 /*
  * static char *rcsid_misc_c =
- *   "$Id: misc.c 4963 2006-09-21 05:50:22Z mwedel $";
+ *   "$Id: misc.c 7552 2007-11-20 20:44:54Z tchize $";
  */
 
 
@@ -110,7 +110,7 @@ int make_path_to_file (char *filename)
 		perror ("Couldn't make path to file");
 		return -1;
 	    }
-	} 
+	}
 	*cp = '/';
     }
     return 0;
@@ -131,6 +131,7 @@ char *strdup_local(const char *str) {
 LogEntry* LogFirst=NULL;
 LogEntry* LogLast=NULL;
 LogListener loglist=NULL;
+int logcount=0;
 int setLogListener(LogListener li){
     if (loglist)
         return 0;
@@ -284,14 +285,6 @@ void logPipe(ChildProcess *child, LogLevel level, int pipe){
 #endif
 }
 
-void unLogPipe(ChildProcess* child, int pipe){
-    if ( (pipe<1) || (pipe>2))/*can't log stdin as it's write only*/
-        return;
-    free(child->logger[pipe].name);
-    child->logger[pipe].name=NULL;
-    child->logger[pipe].log=0;
-}
-
 void logChildPipe(ChildProcess* child, LogLevel level, int flag){
     if (child->flag & flag & CHILD_STDOUT)
         logPipe(child,level,1);
@@ -299,13 +292,6 @@ void logChildPipe(ChildProcess* child, LogLevel level, int flag){
         logPipe(child,level,2);
 }
 
-void unLogChildPipe(ChildProcess* child, int flag){
-    if (flag&CHILD_STDOUT)
-        unLogPipe(child,1);
-    if (flag&CHILD_STDERR)
-        unLogPipe(child,2);
-}
-
 ChildProcess* raiseChild(char* name, int flag){
 #ifndef WIN32
     ChildProcess* cp;
