@@ -26,10 +26,7 @@
 
 #ifndef CPROTO
 /* use declartions from p_cmd.h instead of doing make proto on this file */
- 
-#ifdef WIN32
-#include <windows.h>
-#endif
+
 #include <client.h>
 #include <external.h>
 #include <script.h>
@@ -78,17 +75,17 @@ static void do_clienthelp_list(void) {
     CommCat current_cat = COMM_CAT_MISC;
 #ifndef CLIENTHELP_LONG_LIST
     char line_buf[MAX_BUF];
-    size_t line_len = 0; 
-  
-    line_buf[0] = '\0'; 
+    size_t line_len = 0;
+
+    line_buf[0] = '\0';
 #endif
-    
+
     commands_array = get_cat_sorted_commands();
 
     /* Now we have a nice sorted list. */
 
     H1(" === Client Side Commands === ");
-    
+
     for (i = 0; i < get_num_commands(); i++) {
         commands_copy = commands_array[i];
 
@@ -113,7 +110,7 @@ static void do_clienthelp_list(void) {
 #endif
 
             H2(buf);
-            current_cat = commands_copy->cat; 
+            current_cat = commands_copy->cat;
         }
 
 #ifdef CLIENTHELP_LONG_LIST
@@ -188,14 +185,14 @@ static void show_help(const ConsoleCommand * cc) {
             LINE("This command's documentation is bugged!");
         }
     } else {
-        LINE("This command has no extended documentation. :("); 
+        LINE("This command has no extended documentation. :(");
     }
 }
 
 static void do_clienthelp(const char * arg) {
     const ConsoleCommand * cc;
 
-    if (!arg || !strlen(arg)) { 
+    if (!arg || !strlen(arg)) {
         do_clienthelp_list();
         return;
     }
@@ -208,7 +205,7 @@ static void do_clienthelp(const char * arg) {
         draw_info(buf, NDI_BLACK);
         return;
     }
-    
+
     show_help(cc);
 
 }
@@ -259,13 +256,13 @@ static const char * help_serverhelp(void) {
 
 static void command_help(const char *cpnext) {
     if (cpnext) {
-        const ConsoleCommand * cc;    
+        const ConsoleCommand * cc;
         char buf[MAX_BUF];
-        
+
         cc = find_command(cpnext);
         if (cc != NULL) {
             show_help(cc);
-        } else  {        
+        } else  {
 	    sprintf(buf,"help %s", cpnext);
 	    /* maybe not a must send, but we probably don't want to drop it */
 	    send_command(buf, -1, 1);
@@ -273,8 +270,8 @@ static void command_help(const char *cpnext) {
     } else {
 	do_clienthelp_list();
         /* Now fetch (in theory) command list from the server.
-	TODO Protocol command - feed it to the tab completer. 
-	
+	TODO Protocol command - feed it to the tab completer.
+
 	Nope! It effectivey fetches '/help commands for commands'.
 	*/
 	send_command("help", -1, 1); /* TODO make install in server branch doesn't install def_help. */
@@ -293,10 +290,10 @@ static const char * help_help(void) {
         "the server.\n"
         "\n"
         "With arguments, first checks if there's a client command "
-        "named <topic>. If there is, display it's help. If there " 
+        "named <topic>. If there is, display it's help. If there "
         "isn't, send the topic to the server.\n"
         "\n"
-        "See also: clienthelp, serverhelp.";        
+        "See also: clienthelp, serverhelp.";
 }
 
 
@@ -346,7 +343,7 @@ const char * get_category_name(CommCat cat) {
         case COMM_CAT_SETUP: cat_name = "Configuration"; break;
         case COMM_CAT_SCRIPT: cat_name = "Scripting"; break;
         case COMM_CAT_DEBUG: cat_name = "Debugging"; break;
-        default: cat_name = "PROGRAMMER ERROR"; break; 
+        default: cat_name = "PROGRAMMER ERROR"; break;
     }
 
     return cat_name;
@@ -397,11 +394,6 @@ static void do_magicmap(const char * ignored) {
         draw_magic_map();
 }
 
-static void do_mapredraw(const char * ignored) {
-        /* TODO Okay, maybe we can't let this fall through. It still seems strange. */
-        cs_print_string(csocket.fd, "mapredraw");
-}
-
 static void do_metaserver(const char * ignored) {
         if (!metaserver_get_info(meta_server, meta_port))
             metaserver_show(FALSE);
@@ -432,12 +424,6 @@ static void do_num_free_items(const char * ignored) {
 
 static void do_clienthelp(const char * arg); /* Forward. */
 
-extern void do_filteritem(const char * params); /* filteritem.c - testing only. */
-
-extern void do_filter(const char * params); /* filteritem.c */
-
-extern void do_filters(const char * ignored); /* filteritem.c */
-
 /* Help "typecasters". */
 #include "../help/chelp.h"
 
@@ -449,8 +435,8 @@ static const char * help_magicmap(void) { return HELP_MAGICMAP_LONG; }
 
 static const char * help_inv(void) { return HELP_INV_LONG; }
 
-static const char * help_cwindow(void) { 
-    return 
+static const char * help_cwindow(void) {
+    return
         "Syntax:\n"
         "\n"
         "    cwindow <val>\n"
@@ -467,9 +453,9 @@ static const char * help_script(void) {
         "Syntax:\n"
         "\n"
         "    script <pathname>\n"
-        "\n"        
+        "\n"
 	"Run the program at path <name>"
-	"as a Crossfire client script." 
+	"as a Crossfire client script."
 	"See Documentation/Script.html";
 }
 
@@ -478,13 +464,13 @@ static const char * help_scripttell(void) {
         "Syntax:\n"
         "\n"
         "    scripttell <yourname> <data>\n"
-        "\n"        
+        "\n"
         "?";
 }
 
 /* Toolkit-dependent. */
 static const char * help_savewinpos(void) {
-    return 
+    return
         "Syntax:\n"
         "\n"
         "    savewinpos\n"
@@ -504,7 +490,7 @@ static const char * help_metaserver(void) {
 	"Get updated list of servers "
 	"from the metaserver and show it."
 	"This is the same information that the client "
-	"uses to show a list of servers when it starts.\n"	
+	"uses to show a list of servers when it starts.\n"
 	"\n"
 	"Warning: This command may freeze the client until it gets the list.";
 }
@@ -533,7 +519,7 @@ static const char * help_showweight(void) {
         "no argument given) or your"
         "look-window.";
 }
-	
+
 /*
 *	draw_info("Information Commands", NDI_NAVY);*
 	draw_info(" inv         - *recursively* print your", NDI_BLACK);
@@ -558,12 +544,12 @@ static void do_clienthelp(const char * currently_ignored);
 
 /* TODO Wrap these? Um. */
 static ConsoleCommand CommonCommands[] = {
-    /* From player.h: 
-        name, cat, 
+    /* From player.h:
+        name, cat,
         func, helpfunc,
         long_desc
     */
-    
+
     {
         "autorepeat", COMM_CAT_MISC,
         set_autorepeat, NULL,
@@ -664,12 +650,6 @@ static ConsoleCommand CommonCommands[] = {
         HELP_MAGICMAP_SHORT
     },
 
-    {
-        "mapredraw", COMM_CAT_INFO,
-        do_mapredraw, NULL,
-        NULL
-    },
-
     {
         "metaserver", COMM_CAT_INFO,
         do_metaserver, help_metaserver,
@@ -787,10 +767,10 @@ void init_commands(void) {
     num_commands = CommonCommandsSize + ToolkitCommandsSize;
 #else
     num_commands = CommonCommandsSize;
-#endif    
+#endif
 
     /* Make a list of (pointers to statically allocated!) all the commands.
-       We have a list; the toolkit has a 
+       We have a list; the toolkit has a
        ToolkitCommands and ToolkitCommandsSize, initialized before calling this.
     */
 
@@ -801,11 +781,11 @@ void init_commands(void) {
         name_sorted_commands[i] = &CommonCommands[i];
     }
 
-#ifdef TOOLKIT_COMMANDS    
+#ifdef TOOLKIT_COMMANDS
     for(i = 0; i < ToolkitCommandsSize; i++) {
         name_sorted_commands[CommonCommandsSize + i] = &ToolkitCommands[i];
     }
-#endif    
+#endif
 
     /* Sort them. */
     qsort(name_sorted_commands, num_commands, sizeof(ConsoleCommand *), sort_by_name);
@@ -838,10 +818,10 @@ const ConsoleCommand * find_command(const char * cmd) {
   dummy.name = cmd_cpy;
   dummy_p = &dummy;
   asp_p = bsearch(
-     (void *)&dummy_p, 
-     (void *)name_sorted_commands, 
+     (void *)&dummy_p,
+     (void *)name_sorted_commands,
      num_commands,
-     sizeof(ConsoleCommand *), 
+     sizeof(ConsoleCommand *),
      sort_by_name);
 
   if (asp_p == NULL)
@@ -882,24 +862,24 @@ ConsoleCommand ** get_cat_sorted_commands(void) {
 
 int handle_local_command(const char* cp, const char * cpnext) {
     const ConsoleCommand * cc = NULL;
-    
+
     cc = find_command(cp);
 
     if (cc == NULL) {
         return FALSE;
     }
-    
+
     if (cc->dofunc == NULL) {
         char buf[MAX_BUF];
 
-        snprintf(buf, MAX_BUF - 1, "Client command %s has no implementation!", cc->name); 
-	draw_info(buf, NDI_RED);    
-	
+        snprintf(buf, MAX_BUF - 1, "Client command %s has no implementation!", cc->name);
+	draw_info(buf, NDI_RED);
+
 	return FALSE;
     }
-    
+
     cc->dofunc(cpnext);
-    
+
     return TRUE;
 }
 
@@ -959,9 +939,9 @@ void extended_command(const char *ocommand) {
  * ideally it should stay somewhat up to date with regards to
  * the commands the server supports.
  */
- 
+
 /* TODO Dynamically generate. */
- 
+
 static const char *const commands[] = {
 "accuse", "afk", "apply", "applymode", "archs", "beg", "bleed", "blush",
 "body", "bounce", "bow", "bowmode", "brace", "build", "burp", "cackle", "cast",
@@ -985,7 +965,7 @@ static const char *const commands[] = {
 };
 #define NUM_COMMANDS ((int)(sizeof(commands) / sizeof(char*)))
 
-/* Player has entered 'command' and hit tab to complete it.  
+/* Player has entered 'command' and hit tab to complete it.
  * See if we can find a completion.  Returns matching
  * command. Returns NULL if no command matches.
  */
@@ -1007,7 +987,7 @@ const char * complete_command(const char *command)
            wet #?
 
          If we type 'w' then hit tab, put in the e.
-    
+
        Basically part of bash (readline?)'s behaviour.
     */
 
@@ -1045,7 +1025,7 @@ const char * complete_command(const char *command)
     /*
      * Append a space to allow typing arguments. For commands without arguments
      * the excess space should be stripped off automatically.
-     */ 
+     */
     snprintf(result, sizeof(result), "%s ", match);
 
     return result;
