@@ -19,7 +19,6 @@ void handle_query(char *data, int len);
 void send_reply(const char *text);
 void PlayerCmd(unsigned char *data, int len);
 void item_actions(item *op);
-void Item1Cmd(unsigned char *data, int len);
 void Item2Cmd(unsigned char *data, int len);
 void UpdateItemCmd(unsigned char *data, int len);
 void DeleteItem(unsigned char *data, int len);
@@ -28,8 +27,6 @@ void AddspellCmd(unsigned char *data, int len);
 void UpdspellCmd(unsigned char *data, int len);
 void DeleteSpell(unsigned char *data, int len);
 void NewmapCmd(unsigned char *data, int len);
-void Map1Cmd(unsigned char *data, int len);
-void Map1aCmd(unsigned char *data, int len);
 void Map2Cmd(unsigned char *data, int len);
 void map_scrollCmd(char *data, int len);
 int ExtSmooth(unsigned char *data, int len, int x, int y, int layer);
@@ -39,14 +36,10 @@ void SinkCmd(unsigned char *data, int len);
 void TickCmd(uint8 *data, int len);
 /* image.c */
 void init_common_cache_data(void);
-void requestsmooth(int pnum);
 void requestface(int pnum, char *facename);
 void finish_face_cmd(int pnum, uint32 checksum, int has_sum, char *face, int faceset);
 void reset_image_cache_data(void);
-void FaceCmd(unsigned char *data, int len);
-void Face1Cmd(unsigned char *data, int len);
 void Face2Cmd(uint8 *data, int len);
-void ImageCmd(uint8 *data, int len);
 void Image2Cmd(uint8 *data, int len);
 void display_newpng(int face, uint8 *buf, int buflen, int setnum);
 void get_image_info(uint8 *data, int len);
@@ -60,7 +53,6 @@ void init_client_vars(void);
 void reset_player_data(void);
 void reset_client_vars(void);
 /* item.c */
-void init_item_types(void);
 uint8 get_type_from_name(const char *name);
 void update_item_sort(item *it);
 char *get_number(uint32 i);
@@ -78,12 +70,13 @@ item *map_item(void);
 void update_item(int tag, int loc, char *name, int weight, int face, int flags, int anim, int animspeed, uint32 nrof, int type);
 void print_inventory(item *op);
 void animate_objects(void);
+int can_write_spell_on(item *it);
+void inscribe_magical_scroll(item *scroll, Spell *spell);
 /* mapdata.c */
 void mapdata_init(void);
 void mapdata_reset(void);
 void mapdata_set_size(int viewx, int viewy);
 int mapdata_is_inside(int x, int y);
-void mapdata_set_face(int x, int y, int darkness, sint16 face0, sint16 face1, sint16 face2);
 void mapdata_clear_space(int x, int y);
 void mapdata_set_check_space(int x, int y);
 void mapdata_set_darkness(int x, int y, int darkness);
@@ -98,6 +91,13 @@ sint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh);
 sint16 mapdata_bigface_head(int x, int y, int layer, int *ww, int *hh);
 void mapdata_animation(void);
 /* metaserver.c */
+size_t metaserver2_writer(void *ptr, size_t size, size_t nmemb, void *data);
+void *metaserver2_thread(void *junk);
+int metaserver2_get_info(void);
+void init_metaserver(void);
+void *metaserver1_thread(void *junk);
+int metaserver1_get_info(void);
+int metaserver_check_status(void);
 int metaserver_get_info(char *metaserver, int meta_port);
 void metaserver_show(int show_selection);
 int metaserver_select(char *sel);
@@ -113,9 +113,7 @@ void LOG(LogLevel level, const char *origin, const char *format, ...);
 void purgePipe(ChildProcess *cp, int pipe);
 void monitorChilds(void);
 void logPipe(ChildProcess *child, LogLevel level, int pipe);
-void unLogPipe(ChildProcess *child, int pipe);
 void logChildPipe(ChildProcess *child, LogLevel level, int flag);
-void unLogChildPipe(ChildProcess *child, int flag);
 ChildProcess *raiseChild(char *name, int flag);
 /* newsocket.c */
 void SockList_Init(SockList *sl, uint8 *buf);
