@@ -91,6 +91,13 @@ void
 on_menu_wands_rods_horns_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_menu_jewels_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+void
+on_menu_flesh_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_menu_all_weapons_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -304,3 +311,17 @@ on_configure_activate                  (GtkMenuItem     *menuitem,
 void
 on_save_window_position_activate       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+void
+on_about_close_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_window_destroy_event                (GtkObject       *object,
+                                        gpointer         user_data);
+
+gboolean
+on_metaserver_text_entry_key_press_event
+                                        (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data);
