@@ -1,9 +1,9 @@
 char *rcsid_gtk2_inventory_c =
-    "$Id: inventory.c 5078 2006-11-04 08:39:10Z mwedel $";
+    "$Id: inventory.c 6800 2007-07-22 20:26:49Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2005 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2005-2007 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -82,6 +82,7 @@ static int num_inv_notebook_pages=0;
 
 typedef struct {
     const char *name;		/* Name of this page, for use with the show command */
+    const char *tooltip;	/* Tooltip for menu */
     const char *const *xpm;	/* Icon to draw for the notebook selector */
     int(*show_func) (item *it);	/* Function that takes an item and */
 				/* returns INV_SHOW_* above on whether to show this */
@@ -104,16 +105,16 @@ static int show_locked(item *it)    { return (it->locked?(INV_SHOW_ITEM|INV_SHOW
 static int show_unlocked(item *it)  { return (it->locked?0:(INV_SHOW_ITEM|INV_SHOW_COLOR)); }
 
 Notebook_Info	inv_notebooks[NUM_INV_LISTS] = {
-{"all", all_xpm, show_all, INV_TREE},
-{"applied", hand_xpm, show_applied, INV_TREE},
-{"unapplied", hand2_xpm, show_unapplied, INV_TREE},
-{"unpaid", coin_xpm, show_unpaid, INV_TREE},
-{"cursed", skull_xpm, show_cursed, INV_TREE},
-{"magical", mag_xpm, show_magical, INV_TREE},
-{"nonmagical", nonmag_xpm, show_nonmagical, INV_TREE},
-{"locked", lock_xpm, show_locked, INV_TREE},
-{"unlocked", unlock_xpm, show_unlocked, INV_TREE},
-{"icons", NULL, show_all, INV_TABLE}
+{"all", "All Items", all_xpm, show_all, INV_TREE},
+{"applied", "Applied Items", hand_xpm, show_applied, INV_TREE},
+{"unapplied", "Unapplied Items", hand2_xpm, show_unapplied, INV_TREE},
+{"unpaid", "Unpaid items", coin_xpm, show_unpaid, INV_TREE},
+{"cursed", "Cursed items", skull_xpm, show_cursed, INV_TREE},
+{"magical", "Magical items", mag_xpm, show_magical, INV_TREE},
+{"nonmagical", "Nonmagical items", nonmag_xpm, show_nonmagical, INV_TREE},
+{"locked", "Inventory locked items", lock_xpm, show_locked, INV_TREE},
+{"unlocked", "Inventory unlocked items",unlock_xpm, show_unlocked, INV_TREE},
+{"icons", "Quick icon view", NULL, show_all, INV_TABLE}
 };
 
 
@@ -182,7 +183,7 @@ static void list_item_action(GdkEventButton *event, item *tmp)
 	     * to the ground (dest=0).  Have to look at the item environment,
 	     * because what list is no longer accurate.
 	     */
-	    if (env & (ITEM_GROUND | ITEM_IN_CONTAINER)) 
+	    if (env & (ITEM_GROUND | ITEM_IN_CONTAINER))
 		dest = cpl.ob->tag;
 	    else if (env == ITEM_INVENTORY && cpl.container &&
 		     (get_item_env(cpl.container) == ITEM_INVENTORY ||
@@ -320,12 +321,14 @@ static void setup_list_columns(GtkWidget *treeview)
     column = gtk_tree_view_column_new_with_attributes ("Weight", renderer,
                                                       "text", LIST_WEIGHT,
                                                       NULL);
-    /* 50 is just a guess.  However, testing showed that with auto resize,
-     * the name column for some objects is very long, which causes weight
-     * column to be pushed off the right edge and not fully visible.  Given
-     * the choice, I'd rather have the name truncated.
+    /* At 50, the title was always truncated on some systems.  64 is the
+     * minimum on those systems for it to be possible to avoid truncation
+     * at all.  Truncating the title looks cheesy, especially since heavy
+     * items (100+) need the width of the field anyway.  If weight pushed
+     * off the edge is a problem, it would be just better to let the user
+     * resize or find a way to allow rendering with a smaller font.
      */
-    gtk_tree_view_column_set_min_width(column, 50);
+    gtk_tree_view_column_set_min_width(column, 64);
     gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
 
     gtk_tree_view_column_set_sort_column_id(column, LIST_WEIGHT);
@@ -388,10 +391,25 @@ void inventory_init(GtkWidget *window_root)
 	if (inv_notebooks[i].type == INV_TREE) {
 	    swindow = gtk_scrolled_window_new(NULL, NULL);
 	    gtk_widget_show(swindow);
-	    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swindow), 
+	    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swindow),
 					   GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
 	    image = gtk_image_new_from_pixbuf(
 		      gdk_pixbuf_new_from_xpm_data((const char**)inv_notebooks[i].xpm));
+
+
+	    if (inv_notebooks[i].tooltip) {
+		GtkWidget *eb;
+
+		eb=gtk_event_box_new();
+		gtk_widget_show(eb);
+
+		gtk_container_add(GTK_CONTAINER(eb), image);
+		gtk_widget_show(image);
+
+		image=eb;
+		gtk_tooltips_set_tip(inv_table_tooltips, image, inv_notebooks[i].tooltip, NULL);
+	    }
+
 	    gtk_notebook_insert_page(GTK_NOTEBOOK(inv_notebook), swindow, image, i);
 
 	    inv_notebooks[i].treestore = gtk_tree_store_new (LIST_NUM_COLUMNS,
@@ -422,7 +440,7 @@ void inventory_init(GtkWidget *window_root)
 
     /* If all the data is set up properly, these should match */
     if (num_inv_notebook_pages != NUM_INV_LISTS) {
-	LOG(LOG_ERROR,"inventory.c:inventory_init", 
+	LOG(LOG_ERROR,"inventory.c:inventory_init",
 	    "num_inv_notebook_pages (%d) does not match NUM_INV_LISTS(%d)\n",
 	    num_inv_notebook_pages, NUM_INV_LISTS);
     }
@@ -463,7 +481,7 @@ void command_show (char *params)
 	 */
 	if (gtk_notebook_get_current_page(GTK_NOTEBOOK(inv_notebook))==num_inv_notebook_pages)
 	    gtk_notebook_set_page(GTK_NOTEBOOK(inv_notebook), 0);
-	else 
+	else
 	    gtk_notebook_next_page(GTK_NOTEBOOK(inv_notebook));
 
     } else {
@@ -491,7 +509,7 @@ void set_weight_limit (uint32 wlim)
 
 /* returns the color to use for this object, based on
  * it being cursed and whatnot.  Right now, we only use
- * the background bolor, but decided to make this extensible
+ * the background color, but decided to make this extensible
  * to also cover the foreground (perhaps in the future).
  * perhaps also font information should be listed, so the
  * font could be made bold, italic, etc.
@@ -542,7 +560,7 @@ void item_event_item_changed(item * it) {}
  *    then this creates a real tree, for things like containers.
  * color - if true, do foreground/background colors, otherwise, just black & white
  */
-static void add_object_to_store(item *it, GtkTreeStore *store, 
+static void add_object_to_store(item *it, GtkTreeStore *store,
 				GtkTreeIter *new, GtkTreeIter *parent, int color)
 {
     char    buf[256], buf1[256];
@@ -683,8 +701,8 @@ drawingarea_inventory_table_expose_event        (GtkWidget       *widget,
      * before the list is updated - if so, don't draw stuff we don't
      * have faces for.
      */
-    if (tmp->face) 
-	gdk_draw_pixbuf(widget->window, NULL, 
+    if (tmp->face)
+	gdk_draw_pixbuf(widget->window, NULL,
 			(GdkPixbuf*)pixmaps[tmp->face]->icon_image,
 			0, 0, 0, 0, image_size, image_size, GDK_RGB_DITHER_NONE, 0, 0);
     return TRUE;
@@ -695,7 +713,7 @@ drawingarea_inventory_table_expose_event        (GtkWidget       *widget,
 Right click drops the object.  Shift left click locks/unlocks the object.  Shift \
 middle click marks the object"
 
-/* draws the table of image icons. 
+/* draws the table of image icons.
  * if 'animate' is non zero, then this is an animation run -
  * flip the animation state of the objects, and only draw
  * those that need to be drawn.
@@ -721,9 +739,9 @@ void draw_inv_table(int animate)
 	if (num_items % columns) rows++;
     }
     if (rows > MAX_INV_ROWS) rows=MAX_INV_ROWS;
-    
+
     gtk_table_resize(GTK_TABLE(inv_table), rows, columns);
-	
+
     x=0;
     y=0;
     for (tmp=cpl.ob->inv; tmp; tmp=tmp->next) {
@@ -750,7 +768,7 @@ void draw_inv_table(int animate)
 		    tmp->last_anim=0;
 
 		    gdk_window_clear(inv_table_children[x][y]->window);
-		    gdk_draw_pixbuf(inv_table_children[x][y]->window, NULL, 
+		    gdk_draw_pixbuf(inv_table_children[x][y]->window, NULL,
 			(GdkPixbuf*)pixmaps[tmp->face]->icon_image,
 			0, 0, 0, 0, image_size, image_size, GDK_RGB_DITHER_NONE, 0, 0);
 		}
@@ -760,19 +778,19 @@ void draw_inv_table(int animate)
 	    /* Need to clear out the old signals, since the signals are effectively
 	     * stacked - you can have 6 signal handlers tied to the same function.
 	     */
-	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y], 
-			G_SIGNAL_MATCH_FUNC, 0, 0, NULL, 
+	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y],
+			G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
 			G_CALLBACK (drawingarea_inventory_table_button_press_event),
 			NULL);
 
-	    if (handler) 
+	    if (handler)
 		g_signal_handler_disconnect((gpointer) inv_table_children[x][y], handler);
 
-	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y], 
-			G_SIGNAL_MATCH_FUNC, 0, 0, NULL, 
+	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y],
+			G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
 			G_CALLBACK (drawingarea_inventory_table_expose_event),
 			NULL);
-	    if (handler) 
+	    if (handler)
 		g_signal_handler_disconnect((gpointer) inv_table_children[x][y], handler);
 
 	    /* Not positive precisely what events are need, but some events
@@ -790,7 +808,7 @@ void draw_inv_table(int animate)
 		tmp);
 
 	    gdk_window_clear(inv_table_children[x][y]->window);
-	    gdk_draw_pixbuf(inv_table_children[x][y]->window, NULL, 
+	    gdk_draw_pixbuf(inv_table_children[x][y]->window, NULL,
 			(GdkPixbuf*)pixmaps[tmp->face]->icon_image,
 			0, 0, 0, 0, image_size, image_size, GDK_RGB_DITHER_NONE, 0, 0);
 
@@ -821,19 +839,19 @@ void draw_inv_table(int animate)
 	if (inv_table_children[x][y]) {
 	    gdk_window_clear(inv_table_children[x][y]->window);
 
-	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y], 
-			G_SIGNAL_MATCH_FUNC, 0, 0, NULL, 
+	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y],
+			G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
 			G_CALLBACK (drawingarea_inventory_table_button_press_event),
 			NULL);
 
-	    if (handler) 
+	    if (handler)
 		g_signal_handler_disconnect((gpointer) inv_table_children[x][y], handler);
 
-	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y], 
-			G_SIGNAL_MATCH_FUNC, 0, 0, NULL, 
+	    handler = g_signal_handler_find((gpointer)inv_table_children[x][y],
+			G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
 			G_CALLBACK (drawingarea_inventory_table_expose_event),
 			NULL);
-	    if (handler) 
+	    if (handler)
 		g_signal_handler_disconnect((gpointer) inv_table_children[x][y], handler);
 
 	    /* Hide the widget so that the tooltips doesn't show up */
@@ -900,7 +918,7 @@ void draw_lists ()
  * and if they change tabs, draw the new tab and get rid of the
  * old info.
  * Ideally, I'd like to call draw_inv() from this function,
- * but there is some oddity 
+ * but there is some oddity
  */
 void
 on_notebook_switch_page                (GtkNotebook     *notebook,
@@ -960,8 +978,8 @@ void animate_inventory()
     valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(store), &iter);
 
     while (valid) {
-	gtk_tree_model_get (GTK_TREE_MODEL(store), &iter, 
-                          LIST_OBJECT, &tmp, 
+	gtk_tree_model_get (GTK_TREE_MODEL(store), &iter,
+                          LIST_OBJECT, &tmp,
                           -1);
 
 	/* This is an object with animations */
