@@ -1,5 +1,5 @@
 char *rcsid_gtk2_menubar_c =
-    "$Id: menubar.c,v 1.2 2006/02/20 07:22:04 mwedel Exp $";
+    "$Id: menubar.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -29,6 +29,9 @@ char *rcsid_gtk2_menubar_c =
 #  include <config.h>
 #endif
 
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <gtk/gtk.h>
 
 #include "client.h"
@@ -37,6 +40,7 @@ char *rcsid_gtk2_menubar_c =
 #include "interface.h"
 #include "support.h"
 #include "p_cmd.h"
+#include "main.h"
 
 /* Few quick notes on the menubar:
  * 1) Using the stock Quit menu item for some reason causes it to
@@ -86,11 +90,19 @@ menu_quit_character                       (GtkMenuItem     *menuitem,
 
 }
 
+/* This function enables/disables some of the menubar options.  Some do
+ * not make sense if not connected to the server, so should be
+ * disabled until connected.
+ * enable is a true/false value. If true, enable the items, if false,
+ * disable them.
+ */
 
-void
-menu_about                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+void enable_menu_items(int enable)
 {
 
-}
+    gtk_widget_set_sensitive(lookup_widget(window_root,"quit_character1"), enable);
+    gtk_widget_set_sensitive(lookup_widget(window_root,"disconnect"), enable);
+    gtk_widget_set_sensitive(lookup_widget(window_root,"spells"), enable);
+    gtk_widget_set_sensitive(lookup_widget(window_root,"pickup1"), enable);
 
+}
