@@ -1,5 +1,5 @@
 char *rcsid_gtk2_metaserver_c =
-    "$Id: metaserver.c 4889 2006-09-06 07:27:06Z mwedel $";
+    "$Id: metaserver.c 8268 2008-01-25 03:23:13Z kbulgrien $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -36,6 +36,7 @@ char *rcsid_gtk2_metaserver_c =
 #include "support.h"
 #include "metaserver.h"
 #include "main.h"
+#include <pthread.h>
 
 static GtkWidget *metaserver_window, *treeview_metaserver, *metaserver_button,
     *metaserver_status, *metaserver_entry;
@@ -59,7 +60,7 @@ gboolean metaserver_selection_func (
     return TRUE;
 }
 
-char *get_metaserver()
+get_metaserver()
 {
     static int has_init=0;
     GtkTreeIter iter;
@@ -96,22 +97,24 @@ char *get_metaserver()
         gtk_tree_view_column_set_sort_column_id(column, LIST_HOSTNAME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview_metaserver), column);
 
+	/*
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes ("IP Addr", renderer,
                                                       "text", LIST_IPADDR,
                                                       NULL);
         gtk_tree_view_column_set_sort_column_id(column, LIST_IPADDR);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview_metaserver), column);
+	*/
 
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes ("Last Update (Sec)", renderer,
+	column = gtk_tree_view_column_new_with_attributes ("Updated (Sec)", renderer,
                                                       "text", LIST_IDLETIME,
                                                       NULL);
         gtk_tree_view_column_set_sort_column_id(column, LIST_IDLETIME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview_metaserver), column);
 
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes ("# Players", renderer,
+	column = gtk_tree_view_column_new_with_attributes ("Players", renderer,
                                                       "text", LIST_PLAYERS,
                                                       NULL);
         gtk_tree_view_column_set_sort_column_id(column, LIST_PLAYERS);
@@ -139,7 +142,7 @@ char *get_metaserver()
     }
     gtk_widget_show(metaserver_window);
 
-    gtk_label_set_text(GTK_LABEL(metaserver_status), "Waiting for user selection");
+    gtk_label_set_text(GTK_LABEL(metaserver_status), "Waiting for data from metaserver");
 
     metaserver_txt = gtk_entry_get_text(GTK_ENTRY(metaserver_entry));
     if (*metaserver_txt == '\0') {
@@ -150,6 +153,13 @@ char *get_metaserver()
 
     gtk_list_store_clear(store_metaserver);
 
+    while (metaserver_check_status()) {
+	usleep(100);
+	gtk_main_iteration_do(FALSE);
+    }
+	
+    pthread_mutex_lock(&ms2_info_mutex);
+
     if (cached_servers_num) {
         for ( i = 0; i < cached_servers_num; i++ ) {
 	    for (j=0; j < meta_numservers; j++) {
@@ -158,7 +168,7 @@ char *get_metaserver()
 	    }
 	    if (j == meta_numservers) {
 		gtk_list_store_append(store_metaserver, &iter);
-		gtk_list_store_set(store_metaserver, &iter, 
+		gtk_list_store_set(store_metaserver, &iter,
 			       LIST_HOSTNAME, cached_servers_name[i],
 			       LIST_IPADDR, cached_servers_ip[i],
 			       LIST_COMMENT, "Cached server entry",
@@ -167,26 +177,33 @@ char *get_metaserver()
 	}
     }
 
+
+    qsort(meta_servers, meta_numservers, sizeof(Meta_Info), (int (*)(const void *, const void *))meta_sort);
+
     for (i=0; i<meta_numservers; i++) {
-	gtk_list_store_append(store_metaserver, &iter);
-	gtk_list_store_set(store_metaserver, &iter, 
+	if (check_server_version(i)){
+	    gtk_list_store_append(store_metaserver, &iter);
+	    gtk_list_store_set(store_metaserver, &iter,
 			       LIST_HOSTNAME, meta_servers[i].hostname,
 			       LIST_IPADDR, meta_servers[i].hostname,
 			       LIST_IDLETIME,  meta_servers[i].idle_time,
-			       LIST_PLAYERS, meta_servers[i].players,
+			       LIST_PLAYERS, meta_servers[i].num_players,
 			       LIST_VERSION, meta_servers[i].version,
-			       LIST_COMMENT, meta_servers[i].comment,
+			       LIST_COMMENT, meta_servers[i].text_comment,
 			       -1);
+	}
     }
+    pthread_mutex_unlock(&ms2_info_mutex);
     if (server) {
 	gtk_list_store_append(store_metaserver, &iter);
-	gtk_list_store_set(store_metaserver, &iter, 
+	gtk_list_store_set(store_metaserver, &iter,
 			       LIST_HOSTNAME, server,
 			       LIST_COMMENT, "default server",
 			       -1);
     }
 
     cpl.input_state = Metaserver_Select;
+    gtk_label_set_text(GTK_LABEL(metaserver_status), "Waiting for user selection");
 
     enable_menu_items(FALSE);
     /* draw_map() is to just redraw the splash */
@@ -195,7 +212,6 @@ char *get_metaserver()
 
     gtk_widget_hide(metaserver_window);
     enable_menu_items(TRUE);
-    return cpl.input_text;
 }
 
 
@@ -246,13 +262,21 @@ on_metaserver_select_clicked           (GtkButton       *button,
 
 static void metaserver_connect_to(const char *name, const char *ip)
 {
-    char  buf[256];
+    char  buf[256], *cp, newname[256];
+    int port=use_config[CONFIG_PORT];
 
     snprintf(buf, 255, "Trying to connect to %s", name);
 
     gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
+    strncpy(newname, name, 255);
+    newname[255]=0;
 
-    csocket.fd=init_connection((char*)(ip?ip:name), use_config[CONFIG_PORT]);
+    if ((cp=strchr(newname,':'))!=NULL) {
+	port = atoi(cp+1);
+	*cp=0;
+    }
+
+    csocket.fd=init_connection((char*)(ip?ip:newname), port);
     if (csocket.fd==-1) {
 	snprintf(buf, 255, "Unable to connect to %s!", name);
 	gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
@@ -318,4 +342,3 @@ on_metaserver_text_entry_key_press_event
     gtk_tree_selection_unselect_all(metaserver_selection);
     return FALSE;
 }
-
