@@ -1,5 +1,5 @@
 char *rcsid_gtk_sdl_c =
-    "$Id: sdl.c 5088 2006-11-06 05:54:03Z mwedel $";
+    "$Id: sdl.c 6716 2007-06-27 18:57:31Z akirschbaum $";
 
 /*
     Crossfire client, a client program for the crossfire program.
@@ -23,7 +23,7 @@ char *rcsid_gtk_sdl_c =
     The author can be reached via e-mail to crossfire@metalforge.org
 */
 
-#include "config.h"
+#include <config.h>
 
 #ifdef HAVE_SDL
 
@@ -132,7 +132,7 @@ static void overlay_grid( int re_init, int ax, int ay)
   /* Need to convert back to screen coordinates */
   ax-= pl_pos.x;
   ay-= pl_pos.y;
-  
+
   if( re_init == TRUE)
     {
       if( grid_overlay)
@@ -144,7 +144,7 @@ static void overlay_grid( int re_init, int ax, int ay)
 
   if( grid_overlay == NULL)
     {
-      grid_overlay= SDL_CreateRGBSurface( SDL_HWSURFACE|SDL_SRCALPHA, 
+      grid_overlay= SDL_CreateRGBSurface( SDL_HWSURFACE|SDL_SRCALPHA,
 					  use_config[CONFIG_MAPWIDTH]*map_image_size,
 					  use_config[CONFIG_MAPHEIGHT]*map_image_size,
 					  mapsurface->format->BitsPerPixel,
@@ -160,8 +160,8 @@ static void overlay_grid( int re_init, int ax, int ay)
       first_pass= 0;
     }
 
-  /* 
-   * If this is our first time drawing the grid, we need to build up the 
+  /*
+   * If this is our first time drawing the grid, we need to build up the
    * grid overlay
    */
   if( first_pass== 0)
@@ -170,7 +170,7 @@ static void overlay_grid( int re_init, int ax, int ay)
       /* Red pixels around the edge and along image borders
        * fully transparent pixels everywhere else
        */
-      
+
       fmt= grid_overlay->format;
       for( x= 0; x < map_image_size*use_config[CONFIG_MAPWIDTH]; x++)
 	{
@@ -179,13 +179,13 @@ static void overlay_grid( int re_init, int ax, int ay)
 	      /* FIXME: Only works for 32 bit displays right now */
 	      pixel= (Uint32*)grid_overlay->pixels+y*grid_overlay->pitch/4+x;
 
-	      if( x == 0 || y == 0 || 
+	      if( x == 0 || y == 0 ||
 		  ((x % map_image_size) == 0) || ((y % map_image_size) == 0 ) ||
 		  y == use_config[CONFIG_MAPHEIGHT]*map_image_size-1 || x == use_config[CONFIG_MAPWIDTH]*map_image_size -1 )
 		{
 		  *pixel= SDL_MapRGBA( fmt, 255, 0, 0, SDL_ALPHA_OPAQUE);
 		}
-	      else 
+	      else
 		{
 		  *pixel= SDL_MapRGBA( fmt, 0, 0, 0, SDL_ALPHA_TRANSPARENT);
 		}
@@ -193,7 +193,7 @@ static void overlay_grid( int re_init, int ax, int ay)
 	}
       first_pass= 1;
 
-      /* 
+      /*
        * If this is our first pass then we need to overlay the entire grid
        * now. Otherwise we just update the tile we are on
        */
@@ -202,8 +202,8 @@ static void overlay_grid( int re_init, int ax, int ay)
       dst.w= map_image_size*use_config[CONFIG_MAPWIDTH];
       dst.h= map_image_size*use_config[CONFIG_MAPHEIGHT];
       SDL_BlitSurface( grid_overlay, NULL, mapsurface, &dst);
-    } 
-  else 
+    }
+  else
     {
       dst.x= ax* map_image_size;
       dst.y= ay* map_image_size;
@@ -223,7 +223,7 @@ static void overlay_grid( int re_init, int ax, int ay)
  * be 'drawingarea'. The second is a boolean, if 0 then the whole
  * SDL system in initialized or reinited if already run once before,
  * if non zero then only the lightmap is rebuilt, if we switch between
- * per-pixel or per-tile lighting 
+ * per-pixel or per-tile lighting
  */
 void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 {
@@ -240,8 +240,8 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 	    SDL_Quit();
 	}
 
-	/* 
-	 * SDL hack to tell SDL which xwindow to paint onto 
+	/*
+	 * SDL hack to tell SDL which xwindow to paint onto
 	 */
 
 #ifndef WIN32
@@ -252,14 +252,14 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
                 GDK_WINDOW_HWND(sdl_window->window) );
 #endif
 	putenv( SDL_windowhack);
-      
+
 	if( SDL_Init( SDL_INIT_VIDEO) < 0)
 	{
 	    LOG(LOG_CRITICAL,"gtk::init_SDL", "Could not initialize SDL: %s", SDL_GetError());
 	    gtk_main_quit();
 	}
 
-	mapsurface= SDL_SetVideoMode( map_image_size*use_config[CONFIG_MAPWIDTH], map_image_size*use_config[CONFIG_MAPHEIGHT], 0, 
+	mapsurface= SDL_SetVideoMode( map_image_size*use_config[CONFIG_MAPWIDTH], map_image_size*use_config[CONFIG_MAPHEIGHT], 0,
 				    SDL_HWSURFACE|SDL_DOUBLEBUF);
 
 	if( mapsurface == NULL)
@@ -283,7 +283,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 	    do_SDL_error( "SDL_CreateRGBSurface", __FILE__, __LINE__);
 	}
 
-	/* 
+	/*
 	 * This is a persurface alpha value, not an alpha channel value.
 	 * So this surface doesn't actually need a full alpha channel
 	 */
@@ -295,7 +295,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 
     if( just_lightmap != 0 && lightmap)
 	SDL_FreeSurface( lightmap);
-  
+
     lightmap= SDL_CreateRGBSurface( SDL_HWSURFACE|SDL_SRCALPHA, map_image_size,
 				  map_image_size,
 				  mapsurface->format->BitsPerPixel,
@@ -307,7 +307,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
     {
 	do_SDL_error( "SDL_CreateRGBSurface", __FILE__, __LINE__);
     }
-  
+
     if(use_config[CONFIG_LIGHTING] != CFG_LT_TILE)
     {
 	/* Convert surface to have a full alpha channel if we are doing
@@ -333,7 +333,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
 }
 
 
-/* Draw a alpha square on lightmap. Topleft corner is at startx,starty. 
+/* Draw a alpha square on lightmap. Topleft corner is at startx,starty.
  * values for topleft, topright, bottomleft,bottomright corners are knowns
  * This use bilinear interpolation for other points. Width and heights are given
  * for surrouding known values square. Interpolation is done in a small square whose
@@ -344,7 +344,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
  * Note - profile shows this is a very costly function - of a small run,
  * 77% of the time of the cpu time for the client was in this function.
  */
- 
+
 void drawquarterlightmap_sdl(int tl, int tr, int bl, int br,                /*colors*/
 			     int width, int height,                         /*color square size*/
 			     int startx, int starty, int endx, int endy,    /*interpolation region*/
@@ -376,7 +376,7 @@ void drawquarterlightmap_sdl(int tl, int tr, int bl, int br,                /*co
  * top of the exiting map space.
  *
  * TODO: I think it is possible to greatly speed this up by using
- * pre-generated darkness masks.  Doing all the possibilities 
+ * pre-generated darkness masks.  Doing all the possibilities
  * would be 3125 images (5 positions, each with 5 values, 5^5),
  * Doing it based on quadrants would only reduce that to 1024.
  * But I _think_ it may be possible to do this with just 64 images
@@ -480,7 +480,7 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	    dst.y = i;
 	    dst.w = map_image_size;
 	    dst.h = 1;
-	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0, 
+	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0,
 			ALPHA_FUDGE((map_image_half_size - i) * dark1 + i * dark0)/map_image_half_size));
 
 	}
@@ -501,14 +501,14 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	    dst.y = i;
 	    dst.w = map_image_size;
 	    dst.h = 1;
-	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0, 
+	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0,
 			ALPHA_FUDGE(dark0*(map_image_size-i) + dark3*(i-map_image_half_size)) / map_image_half_size));
 	}
 	/* Blit this to the screen now.  Otherwise, we need to look at the alpha values
 	 * and re-average.
 	 */
 
-	dst.x= x * map_image_size; 
+	dst.x= x * map_image_size;
 	dst.y= y * map_image_size;
 	SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);
 
@@ -542,10 +542,10 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	    dst.y = 0;
 	    dst.w = 1;
 	    dst.h = map_image_size;
-	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0, 
+	    SDL_FillRect(lightmap, &dst, SDL_MapRGBA(lightmap->format, 0, 0, 0,
 			ALPHA_FUDGE(dark0*(map_image_size-i) + dark2*(i-map_image_half_size)) / map_image_half_size));
 	}
-	dst.x= x * map_image_size; 
+	dst.x= x * map_image_size;
 	dst.y= y * map_image_size;
 	SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);
     } else if (use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL_BEST ) {
@@ -563,7 +563,7 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	    darky = realloc(darky, map_image_size * sizeof(int));
 	    darkx_allocated = map_image_size;
 	}
-			
+
 	for( dx= 0; dx < map_image_half_size; dx++)
 	    darkx[dx]= (dark4*(map_image_half_size-dx) + dark0*dx) / map_image_half_size;
 	for( dx= map_image_half_size; dx < map_image_size; dx++)
@@ -577,7 +577,7 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	SDL_LockSurface( lightmap);
 
 	for (dx=0; dx<map_image_size; dx++)
-	    for (dy=0; dy<map_image_size; dy++) 
+	    for (dy=0; dy<map_image_size; dy++)
 		putpixel(lightmap, dx, dy, SDL_MapRGBA(lightmap->format, 0, 0, 0,(darkx[dx] + darky[dy])/2));
 #else
 	/*we need additionnal surrounding infos*/
@@ -586,7 +586,7 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 		|| !the_map.cells[mx+1][my-1].have_darkness) dark5 = (dark1+dark2)>>1; /*(fast div 2)*/
 	else dark5 = the_map.cells[mx+1][my-1].darkness;
 
-	if ( (x+1 >= use_config[CONFIG_MAPWIDTH]) 
+	if ( (x+1 >= use_config[CONFIG_MAPWIDTH])
 		|| (y+1 >= use_config[CONFIG_MAPHEIGHT])
 		|| !the_map.cells[mx+1][my+1].have_darkness) dark6 = (dark2+dark3)>>1;
 	else dark6 = the_map.cells[mx+1][my+1].darkness;
@@ -594,7 +594,7 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 	if ( (y+1 >= use_config[CONFIG_MAPHEIGHT]) || (x-1 < 0)
 		|| !the_map.cells[mx-1][my+1].have_darkness) dark7 = (dark3+dark4)>>1;
 	else dark7 = the_map.cells[mx-1][my+1].darkness;
-	
+
 	if ( (x-1 < 0) || (y-1 < 0)
 		|| !the_map.cells[mx-1][my-1].have_darkness) dark8 = (dark4+dark1)>>1;
 	else dark8 = the_map.cells[mx-1][my-1].darkness;
@@ -621,10 +621,10 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 #endif
 	dst.w= map_image_size;
 	dst.h= map_image_size;
-	dst.x= x * map_image_size; 
+	dst.x= x * map_image_size;
 	dst.y= y * map_image_size;
 	SDL_UnlockSurface(lightmap);
-	SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);	
+	SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);
     }
 }
 /* Draw anything in adjacent squares that could smooth on given square
@@ -674,10 +674,10 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
         else if (the_map.cells[emx][emy].smooth[layer]<=the_map.cells[mx][my].smooth[layer]){
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
-        }else{      
+        }else{
             slevels[i]=the_map.cells[emx][emy].smooth[layer];
             sfaces[i]=pixmaps[the_map.cells[emx][emy].heads[layer].face]->smooth_face;
-        }                    
+        }
     }
     /* ok, now we have a list of smoothlevel higher than current square.
      * there are at most 8 different levels. so... let's check 8 times
@@ -690,7 +690,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
             if ( (slevels[i]>0) && (!partdone[i]) &&
                 ((lowest<0) || (slevels[i]<slevels[lowest]))
                )
-                    lowest=i;    
+                    lowest=i;
         }
         if (lowest<0)
             break;   /*no more smooth to do on this square*/
@@ -698,7 +698,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
         /*here we know 'what' to smooth*/
         /* we need to calculate the weight
          * for border and weight for corners.
-         * then we 'markdone' 
+         * then we 'markdone'
          * the corresponding squares
          */
         /*first, the border, which may exclude some corners*/
@@ -716,7 +716,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
                 /*must rmove the weight of a corner if not in smoothing*/
                 weightC&=~cweights[i];
             }
-            
+
         }
         /*We can't do this before since we need the partdone to be adjusted*/
         if (sfaces[lowest]<=0)
@@ -726,8 +726,8 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst){
             continue;  /*picture for smoothing not yet available*/
         }
         /* now, it's quite easy. We must draw using a 32x32 part of
-         * the picture smoothface. 
-         * This part is located using the 2 weights calculated: 
+         * the picture smoothface.
+         * This part is located using the 2 weights calculated:
          * (32*weight,0) and (32*weightC,32)
          */
         if ( (!pixmaps[smoothface]->map_image) ||
@@ -799,7 +799,7 @@ static void update_redrawbitmap(void)
 		 * have a flag just to denote lighting changes, since
 		 * that is handled on a different surface anyways.
 		 */
-		if (use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL || 
+		if (use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL ||
 		    use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL_BEST) {
 		    /* This is where having redrawbitmap bigger pays off - don't have
 		     * to check to see if values are within redrawbitmap is within bounds
@@ -832,7 +832,7 @@ static void display_mapcell(int ax, int ay, int mx, int my)
     /* First, we need to black out this space. */
     dst.x = ax*map_image_size;
     dst.y = ay*map_image_size;
-    dst.w = map_image_size; 
+    dst.w = map_image_size;
     dst.h = map_image_size;
     SDL_FillRect(mapsurface, &dst, SDL_MapRGB(mapsurface->format, 0, 0, 0));
 
@@ -1015,13 +1015,13 @@ int sdl_mapscroll(int dx, int dy)
     /* Don't sdl_gen_map should take care of the redraw */
 
     /* a copy of what pngximage does except sdl specfic
-     * mapsurface->pitch is the length of a scanline in bytes 
+     * mapsurface->pitch is the length of a scanline in bytes
      * including alignment padding
      */
     SDL_LockSurface( mapsurface);
     if( dy < 0) {
 	int offset= mapsurface->pitch * (-dy*map_image_size);
-	memmove( mapsurface->pixels + offset, mapsurface->pixels, 
+	memmove( mapsurface->pixels + offset, mapsurface->pixels,
 		     mapsurface->pitch * (mapsurface->h + dy*map_image_size) );
     }
     else if( dy > 0) {
@@ -1040,7 +1040,7 @@ int sdl_mapscroll(int dx, int dy)
 			     mapsurface->pitch - offset);
 	    }
 	    else {
-		char* start_of_row= mapsurface->pixels + mapsurface->pitch * y; 
+		char* start_of_row= mapsurface->pixels + mapsurface->pitch * y;
 		int offset= ( mapsurface->format->BytesPerPixel * map_image_size * dx);
 		memmove( start_of_row, start_of_row + offset,
 			     mapsurface->pitch - offset);
@@ -1048,7 +1048,7 @@ int sdl_mapscroll(int dx, int dy)
 	}
     }
     SDL_UnlockSurface( mapsurface);
-	    
+
     return 1;
 }
 
