@@ -1,5 +1,5 @@
 char *rcsid_gtk2_sound_c =
-    "$Id: sound.c 5010 2006-10-07 18:29:47Z qal21 $";
+    "$Id: sound.c 6716 2007-06-27 18:57:31Z akirschbaum $";
 
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -30,7 +30,7 @@ char *rcsid_gtk2_sound_c =
  * is responsible for playing sounds.
  */
 
-#include "config.h"
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -87,7 +87,7 @@ int init_sounds(void)
 
     if (fcntl(sound_process->tube[0], F_SETFL, O_NONBLOCK)<0) {
 	/* setting non blocking isn't 100% critical, but a good thing if
-	 * we can do it	
+	 * we can do it
 	 */
 	perror("init_sounds: Warning - unable to set non blocking on sound pipe\n");
     }
