@@ -1,51 +1,21 @@
 /* config.c */
-extern void applyconfig(void);
-extern void saveconfig(void);
+extern void main_window_destroyed(void);
 extern void configdialog(GtkWidget *widget);
 extern void load_defaults(void);
 extern void save_defaults(void);
 /* gx11.c */
-extern void do_network(void);
-extern void event_loop(void);
-extern void end_windows(void);
-extern void button_map_event(GtkWidget *widget, GdkEventButton *event);
 extern void gtk_command_history(int direction);
 extern void gtk_complete_command(void);
 extern void draw_prompt(const char *str);
 extern void draw_info(const char *str, int color);
 extern void draw_color_info(int colr, const char *buf);
 extern void draw_stats(int redraw);
-extern void create_stat_bar(GtkWidget *mtable, gint row, gchar *label, gint bar, GtkWidget **plabel);
 extern void reset_stat_bars(void);
 extern void resize_resistance_table(int resists_show);
 extern void draw_message_window(int redraw);
-extern void aboutdialog(GtkWidget *widget);
-extern void createBugTracker(void);
-extern void bugdialog(GtkWidget *widget);
 extern void cclist_button_event(GtkWidget *gtklist, gint row, gint column, GdkEventButton *event);
-extern void disconnect(GtkWidget *widget);
-extern void shelpdialog(GtkWidget *widget);
-extern void new_menu_pickup(GtkWidget *button, int val);
-extern void menu_pickup0(void);
-extern void menu_pickup1(void);
-extern void menu_pickup2(void);
-extern void menu_pickup3(void);
-extern void menu_pickup4(void);
-extern void menu_pickup5(void);
-extern void menu_pickup6(void);
-extern void menu_pickup7(void);
-extern void menu_pickup10(void);
-extern void menu_who(void);
-extern void menu_apply(void);
-extern void menu_cast(void);
-extern void menu_search(void);
-extern void menu_disarm(void);
-extern void menu_spells(void);
 extern void menu_clear(void);
-extern void sexit(void);
 extern void client_exit(void);
-extern void create_splash(void);
-extern void destroy_splash(void);
 extern void create_windows(void);
 extern void set_scroll(const char *s);
 extern void set_autorepeat(const char *s);
@@ -61,7 +31,7 @@ extern void get_window_coord(GtkWidget *win, int *x, int *y, int *wx, int *wy, i
 extern void save_winpos(void);
 extern void set_window_pos(void);
 extern int init_windows(int argc, char **argv);
-extern void display_map_doneupdate(int redraw);
+extern void display_map_doneupdate(int redraw, int notice);
 extern void display_map_newmap(void);
 extern void resize_map_window(int x, int y);
 extern void display_map_startupdate(void);
@@ -79,7 +49,6 @@ extern void get_inv_display(GtkWidget *frame);
 extern void command_show(const char *params);
 extern void update_list_labels(itemlist *l);
 extern void set_weight_limit(uint32 wlim);
-extern void inventory_update_colorinv(void);
 extern void set_show_weight(const char *s);
 extern void itemlist_set_show_icon(itemlist *l, int new_setting);
 extern void set_show_icon(const char *s);
@@ -108,13 +77,8 @@ extern void ckeyunbind(GtkWidget *gtklist, GdkEventButton *event);
 extern void ckeyentry_callback(GtkWidget *widget, GdkEventKey *event, GtkWidget *window);
 extern void ckeyclear(void);
 /* map.c */
-extern void allocate_map(struct Map *new_map, int ax, int ay);
 extern void reset_map(void);
-extern void print_darkness(void);
-extern void print_map(void);
-extern void set_map_darkness(int x, int y, uint8 darkness);
-extern void display_mapscroll(int dx, int dy);
-extern void reset_map_data(void);
+extern int display_mapscroll(int dx, int dy);
 extern void drawsmooth(int mx, int my, int layer, int picx, int picy);
 extern void gtk_draw_map(int redraw);
 /* png.c */
@@ -125,19 +89,17 @@ extern int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len, GdkPixmap *
 /* sdl.c */
 extern void init_SDL(GtkWidget *sdl_window, int just_lightmap);
 extern void drawquarterlightmap_sdl(int tl, int tr, int bl, int br, int width, int height, int startx, int starty, int endx, int endy, int destx, int desty);
-extern void do_sdl_per_pixel_lighting(int x, int y, int mx, int my);
-extern int sdl_square_need_redraw(int mx, int my);
 extern void sdl_gen_map(int redraw);
-extern void sdl_mapscroll(int dx, int dy);
+extern int sdl_mapscroll(int dx, int dy);
 /* sound.c */
 extern void signal_pipe(int i);
 extern int init_sounds(void);
 extern void SoundCmd(unsigned char *data, int len);
 /* text.c */
-extern void init_text_callbacks();
+extern void init_text_callbacks(void);
 extern media_state write_media(GtkText* textarea, const char* message);
 extern media_state write_media_with_state(GtkText* textarea, const char* message,media_state current_state);
-extern char* getMOTD();
-extern char* get_rules();
-extern news_entry* get_news();
-extern void cleanup_textmanagers();
+extern const char* getMOTD(void);
+extern const char* get_rules(void);
+extern news_entry* get_news(void);
+extern void cleanup_textmanagers(void);
