@@ -1,5 +1,5 @@
 const char *rcsid_gtk_keys_c =
-    "$Id: keys.c 4963 2006-09-21 05:50:22Z mwedel $";
+    "$Id: keys.c 6716 2007-06-27 18:57:31Z akirschbaum $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -27,7 +27,7 @@ const char *rcsid_gtk_keys_c =
  * keys.
  */
 
-#include "config.h"
+#include <config.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #ifndef WIN32
@@ -1236,4 +1236,3 @@ void ckeyclear () {
   gtk_entry_set_text (GTK_ENTRY(cmodentrytext), "");
   gtk_entry_set_text (GTK_ENTRY(ckentrytext), "");
 }
-
