@@ -1,11 +1,11 @@
 /* Client aboutfile */
 gchar *text="\n\
-Thanks for consideration on submitting a bug report\n\
+Thanks for considering submission of a bug report\n\
 You came here either because you clicked on 'Report a bug' in Help menu,\n\
-either because a bug in client showed this window.\n\
+or because a bug in the client has just been displayed in this window.\n\
 To submit a bug report, please go to the following web page\n\n\
 http://sourceforge.net/tracker/?func=add&group_id=13833&atid=113833\n\n\
 and don't forget to add the content of 'MESSAGES TRACK' below.\n\
-If you ran client in console, the output in console may be of interrest too.\n\
-Also don't forget to add any informations you may find useful.";
-
+If you run the client in a console, the output of the console is often\n\
+helpful.  Also don't forget to add other information, like the client\n\
+version, or the GTK version when applicable.";
