@@ -1,5 +1,5 @@
 const char *rcsid_x11_sound_c =
-    "$Id: sound.c 4963 2006-09-21 05:50:22Z mwedel $";
+    "$Id: sound.c 6716 2007-06-27 18:57:31Z akirschbaum $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -27,7 +27,7 @@ const char *rcsid_x11_sound_c =
  * cfsndserv program and sends the writes to it.
  */
 
-#include "config.h"
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -75,7 +75,7 @@ int init_sounds(void)
 
 /* Plays sound 'soundnum'.  soundtype is 0 for normal sounds, 1 for
  * spell_sounds.  This might get extended in the future.  x,y are offset
- * (assumed from player) to play sound.  This information is used to 
+ * (assumed from player) to play sound.  This information is used to
  * determine value and left vs right speaker balance.
  *
  * This procedure seems to be very slow - much slower than I would
@@ -100,7 +100,7 @@ static void play_sound(int soundnum, int soundtype, int x, int y)
 
 
 void SoundCmd(unsigned char *data,  int len)
-{  
+{
     int x, y, num, type;
 
     if (len!=5) {
@@ -118,4 +118,3 @@ void SoundCmd(unsigned char *data,  int len)
 #endif
     play_sound(num, type, x, y);
 }
-
