@@ -35,10 +35,10 @@ extern char *get_metaserver(void);
 extern void check_x_events(void);
 extern int init_windows(int argc, char **argv);
 extern void display_map_newmap(void);
-extern void display_mapcell_pixmap(int ax, int ay);
 extern void resize_map_window(int x, int y);
 extern void x_set_echo(void);
-extern void display_map_doneupdate(int redraw);
+extern void display_map_doneupdate(int redraw, int notice);
+extern int display_mapscroll(int dx, int dy);
 extern int associate_cache_entry(Cache_Entry *ce, int pixnum);
 extern void redisplay_stats(void);
 extern void display_map_startupdate(void);
@@ -53,7 +53,7 @@ extern void command_show(const char *params);
 extern int main(int argc, char *argv[]);
 /* xutil.c */
 extern void init_cache_data(void);
-extern int allocate_colors(Display *disp, Window w, long screen_num, Colormap *colormap, XColor discolor[16]);
+extern void allocate_colors(Display *disp, Window w, long screen_num, Colormap *colormap, XColor discolor[16]);
 extern void parse_keybind_line(char *buf, int line, int standard);
 extern void init_keys(void);
 extern void parse_key_release(KeyCode kc, KeySym ks);
@@ -63,11 +63,5 @@ extern void configure_keys(KeyCode k, KeySym keysym);
 extern void unbind_key(const char *params);
 extern int find_face_in_private_cache(char *face, int checksum);
 extern void image_update_download_status(int start, int end, int total);
-extern void allocate_map(struct Map *new_map, int ax, int ay);
 extern void reset_map(void);
-extern void print_darkness(void);
-extern void print_map(void);
-extern void set_map_darkness(int x, int y, uint8 darkness);
-extern void display_mapscroll(int dx, int dy);
-extern void reset_map_data(void);
-extern void addsmooth(uint16 face, uint smooth_face);
+extern void addsmooth(uint16 face, uint16 smooth_face);
